# puzzleimage
puzzleimage is a repository for making puzzle images.

## How to upload to PyPI?
You can upload to PyPI by just the following steps:
1. Add a tag to a commit.
2. Create a "release" on GitHub.
Then, GitHub actions should work to publish it.